//+-----------------------------------------------------------------------------+
//|                                                    Daily Scalping v1.0a.mq4 |
//|                                                                Skyline 2007 |
//|                                                                             |
//+-----------------------------------------------------------------------------+
#property copyright "Skyline 2007"
#property link      ""
#include <stdlib.mqh>

// v1.0  (07 Feb 2007) : Start Project 
// v1.0a (07 Feb 2007) : Add GMT_Shift variable

//---- Definizione parametri esterni 
extern double    GMT_Shift           = 0;
extern int       TakeProfit          = 0;
extern int       StopLoss            = 40;  
extern int       HourToCloseOrders   = 23;
extern bool      SundayCandleExists  = true;
extern double    Lots                = 0.1; 
extern bool      UseMoneyManagement  = false;
extern int       Risk                = 2;
extern int       MagicNumber         = 11111;
extern int       Slippage            = 3;
 
//----- Definizione parametri interni 
static int TradeStatus = 0; //0 = Trades disabilitati , 1 = Solo Buy permessi, 2 = Solo Sell permessi 


//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   // Calcola dimensione Lot in base all'Equity
   if (UseMoneyManagement==true) Lots = CalcolaLot(Risk);   

   // Attiva ordine alle 00:00 GMT 
   OpenOrderMidnight(Lots);
 
   // Attiva ordini successivi
   OpenNextOrders(Lots);
   
   // Chiude ordini allo scadere di HourToCloseOrders
   CloseAllOrders(HourToCloseOrders);
 
   return(0);
  }
  
// ===== Routine per chiudere tutti gli ordini =====
void CloseAllOrders(int Ora)
{
 int total,cnt;
 
 total = OrdersTotal();
 if ( Hour()==MathMod(Ora+GMT_Shift,24) )
 {
  TradeStatus = 0; // azzera variabile globale per non aprire pi trade
  
  for(cnt=0;cnt<total;cnt++)
  {
   OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
   if (OrderMagicNumber()==MagicNumber)
   {
    if (OrderType() == OP_BUY)  OrderClose(OrderTicket(),OrderLots(), Bid, Slippage, LimeGreen);
    if (OrderType() == OP_SELL) OrderClose(OrderTicket(),OrderLots(), Ask, Slippage, Red);
   }  // if (OrderMagicNumber()==MagicNumber)
  }  // for 
 } // if
}

// ===== Routine per aprire il primo ordine alle 00:00 GMT =====
void OpenOrderMidnight(double Lot)
{  int Ticket,Errore; 
   double SL,TP;
   int ActualSpread;
   
   RefreshRates();
   
   ActualSpread = MarketInfo(Symbol(),MODE_SPREAD);
    
   int Total = OrdersTotal();
   
   if ( Total < 1 && Hour()==MathMod(24+GMT_Shift,24) && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
     TradeStatus = 0; // azzera variabile globale 
      
   // Controlla BUY Order
   if (
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BULLISH") ||
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BEARISH") ||
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BEARISH") ||     
      (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BEARISH")
      )
    {   
      
      // Controlla SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Ask-StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Ask+TakeProfit*Point;
      // Piazza l'ordine BUY
      Ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,SL,TP,"BUY ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 2; // Prossimo trade  Sell
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON BUY ORDER (",Errore,") : ",ErrorDescription(Errore));
      }  
     } 
   }
   
   Total = OrdersTotal();
   
   if ( Total < 1 && Hour()==MathMod(24+GMT_Shift,24) && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
   
     // Controlla SELL Order
     if (
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BEARISH") ||
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BULLISH") ||
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BULLISH") ||
         (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BULLISH")
        )
     {
 
      // Setta SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Bid+StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Bid-TakeProfit*Point;
      
      // Piazza Ordine SELL       
      Ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,SL,TP,"SELL ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 1; // Prossimo trade  Buy
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON SELL ORDER (",Errore,") : ",ErrorDescription(Errore));
      } 
      
     }    
   }
}

// ===== Routine per aprire ordini durante la giornata al raggiungimento dello SL o TP =====
void OpenNextOrders(double Lot)
{  int Ticket,Errore; 
   double SL,TP;
   int ActualSpread;
   
   RefreshRates();
   
   ActualSpread = MarketInfo(Symbol(),MODE_SPREAD);

   int Total = OrdersTotal();
   
   if ( Total < 1 && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
   // Controlla BUY Order
   if ( TradeStatus == 1 )
    {   
      
      // Controlla SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Ask-StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Ask+TakeProfit*Point;
      
      // Piazza l'ordine BUY
      Ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,SL,TP,"BUY ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 2; // Prossimo trade  Sell 
            
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON BUY ORDER (",Errore,") : ",ErrorDescription(Errore));
      }  
     } 
   }
  
   Total = OrdersTotal();
   if ( Total < 1 && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {  
     // Controlla SELL Order
     if ( TradeStatus == 2 )
     {
 
      // Setta SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Bid+StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Bid-TakeProfit*Point;
      
      // Piazza Ordine SELL       
      Ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,SL,TP,"SELL ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 1; // Prossimo trade  Buy
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON SELL ORDER (",Errore,") : ",ErrorDescription(Errore));
      } 
     }    
   }
}

// ===== Routine per controllare il trend ===== 
string CheckTrend(int DaysShift)
{
 if ( SundayCandleExists == true ) 
 {
  if ( DayOfWeek()==1 ) DaysShift = DaysShift+1; // Se esiste la candela di domenica non la prende in considerazione
 }
 if (iOpen(NULL,PERIOD_D1,DaysShift)<=iClose(NULL,PERIOD_D1,DaysShift)) return("BULLISH");
 else return("BEARISH");
}

// ===== Routine per il calcolo del Lot nel caso di Money Management =====
double CalcolaLot(int Rischio)
{
  double Lot=0;
  Lot=AccountEquity()* Rischio/100/1000;
  if( Lot>=0.1 )
  {
    Lot = NormalizeDouble(Lot,1); 
  }
  else Lot = NormalizeDouble(Lot,2);
  if (Lot > MarketInfo(Symbol(),MODE_MAXLOT)) { Lot = MarketInfo(Symbol(),MODE_MAXLOT); } // Avoid possible Lot value overflow if lot exceed maximum value allowed by broker
  if (Lot < MarketInfo(Symbol(),MODE_MINLOT)) { Lot = MarketInfo(Symbol(),MODE_MINLOT); } // Avoid possible Lot value overflow if lot exceed minimum value allowed by broker
  return(Lot);
}

/*
// ===== Routine per controllare BUY chiusi in giornata =====
int ControllaBuyChiusi()
{int i;
 int BuyChiusi=0;
 int hstTotal=HistoryTotal();
 for(i=0;i<hstTotal;i++)
 {
  //---- check selection result
  if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==true)
  { 
   if (
       OrderType()==OP_BUY              && 
       TimeDay(OrderCloseTime())==Day() && 
       OrderMagicNumber()==MagicNumber   
      ) BuyChiusi++;
  } 
 }
 return(BuyChiusi);
}

// ===== Routine per controllare SELL chiusi in giornata =====
int ControllaSellChiusi()
{int i;
 int SellChiusi=0;
 int hstTotal=HistoryTotal();
 for(i=0;i<hstTotal;i++)
 {
  //---- check selection result
  if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==true)
  { 
   if (
       OrderType()==OP_SELL             && 
       TimeDay(OrderCloseTime())==Day() && 
       OrderMagicNumber()==MagicNumber 
      ) SellChiusi++;
  }  
 } 
 return(SellChiusi);
}

// ===== Routine per calcolare ordini chiusi con SL in giornata =====

int StopLossHit()
{ int ContaSL=0;
  int i;
  int hstTotal=HistoryTotal();
  for(i=0;i<hstTotal;i++)
  {
   //---- check selection result
   if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false)
   {
    Print("Access to history failed with error (",GetLastError(),")");
    break;
   }
   else 
   { 
    if (OrderClosePrice()==OrderStopLoss() && TimeDay(Day())==TimeDay(OrderCloseTime())) ContaSL++;
   }
  }
  return(ContaSL);
}
*/
//+------------------------------------------------------------------+